@@ -8,11 +8,11 @@ Information describing the project.
 package = 'bts'
 project = "python api for BitShares"
 project_no_spaces = project.replace(' ', '')
-version = '0.5.16'
+version = '0.6.2'
 description = 'api for BitShares'
 authors = ['Alt']
 authors_string = ', '.join(authors)
-emails = ['pch957@163.com']
+emails = ['pch957@gmail.com']
 license = 'MIT'
 copyright = '2015 ' + authors_string
 url = 'https://github.com/pch957/python-bts'
